#include <stdio.h>

#include <avr/io.h>

#include <motelib/system.h>
#include <motelib/button.h>
#include <motelib/uart.h>
#include <motelib/led.h>
#include <motelib/radio.h>

#define HOST_ADDR 2

uint8_t mode;
uint8_t packet;
uint8_t sending;
uint8_t i;

void ChangeMode();
void SendToHost();

void myInit() {
	DDRC &= 0b11000000;  // make PC0-5 input
	PORTC |= 0b00111111;  // enable pull-up on PC0-5

	mode = 0;
	ledSetValue(0);
	buttonSetHandler(ChangeMode);
	sending = 0;
}

void ChangeMode(ButtonStatus status) {
	if (status == BUTTON_PRESSED) {
		mode = (mode+1)%4;
		ledSetValue(mode!=3? mode:4);
	}
}

void ScanButton() {
	if (sending==0 && mode!=0 && PINC!=0b00111111)
		SendToHost();
}

void SendToHost() {
	packet = ((~PINC)<<2) | (mode&3);
	if (PINC!=0b00111111) {
		sending = 1;
		radioRequestTx(HOST_ADDR, 99, &packet, sizeof(packet), SendToHost);
		printf("%d\r\n", packet);
	}
	else {
		sending = 0;
		packet = mode&3;
		for (i=0;i<20;i++)
			radioRequestTx(HOST_ADDR, 99, &packet, sizeof(packet), NULL);
		printf("%d\r\n", packet);
	}
}

void boot() {
	myInit();
	setLoopRoutine(ScanButton);

	//debug
	uartEnable(true, true);
}
